emapsCifReader Readme
--------------

Introduction
------------

emapsCifReader is built entirely based on source package in PyCifRW-4.4.3 with only package folder names changes to avoid conflicts with original PyCifRW-4.4.3 python package. Its sole purpose is to provides support for pyemaps users with ease of installation on windows platform with precompiled version of the module.

The original PyCifRW package provides support for reading and writing CIF 
(Crystallographic Information Format) files using Python.  

Conformance
-----------

The specifications found in Vol G of the International Tables for
Crystallography were used as a reference for CIF 1.0/1.1 syntax.
http://dx.doi.org/10.1107/S1600576715021871 was used as the CIF 2.0
reference.

PyCifRW has been tested on the IUCr sample CIF1.1 trip files located at
http://www.iucr.org/iucr-top/cif/developers/trip and fails or
successfully reads as it is supposed to (note that `ciftest5` contains
characters now forbidden in CIFs).

License
----------

emapsCifReader is made available using the Python 2.0 license as it is for the original package. 

